@@ -6,12 +6,17 @@ import ctypes
 class allocated_c_char_p(ctypes.c_char_p):
     pass
 
+EXCEPTION_HANDLER_FUNCTYPE = ctypes.CFUNCTYPE(None, ctypes.c_char_p, ctypes.c_char_p)
+
 def prototype(lgeos, geosVersion):
 
+    lgeos.initGEOS.argtypes = [EXCEPTION_HANDLER_FUNCTYPE, EXCEPTION_HANDLER_FUNCTYPE]
     lgeos.initGEOS.restype = None
 
+    lgeos.finishGEOS.argtypes = []
     lgeos.finishGEOS.restype = None
 
+    lgeos.GEOSversion.argtypes = []
     lgeos.GEOSversion.restype = ctypes.c_char_p
 
     lgeos.GEOSGeomFromWKT.restype = ctypes.c_void_p
@@ -259,6 +264,9 @@ def prototype(lgeos, geosVersion):
         # Linear referencing features aren't found in versions 1.5,
         # but not in all libs versioned 1.6.0 either!
         if hasattr(lgeos, 'GEOSProject'):
+            lgeos.GEOSSingleSidedBuffer.restype = ctypes.c_void_p
+            lgeos.GEOSSingleSidedBuffer.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_int, ctypes.c_int, ctypes.c_double, ctypes.c_int]
+
             lgeos.GEOSProject.restype = ctypes.c_double
             lgeos.GEOSProject.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
 
@@ -274,3 +282,7 @@ def prototype(lgeos, geosVersion):
             lgeos.GEOSInterpolateNormalized.argtypes = [ctypes.c_void_p, 
                                                         ctypes.c_double]
 
+    # TODO: Find out what version of geos_c came with geos 3.3.0
+    if geosVersion >= (1, 6, 3):
+        lgeos.GEOSUnaryUnion.restype = ctypes.c_void_p
+        lgeos.GEOSUnaryUnion.argtypes = [ctypes.c_void_p]
